pub struct EntropyValidator { /* private fields */ }Expand description
Entropy validator for cryptographic inputs
This validator provides utilities to validate the entropy quality of cryptographic inputs to ensure they meet security requirements.
Implementations
Sourceimpl EntropyValidator
impl EntropyValidator
Sourcepub fn validate_key_entropy(&self, key_data: &[u8]) -> Result<()>
pub fn validate_key_entropy(&self, key_data: &[u8]) -> Result<()>
Sourcepub fn set_min_entropy_bits(&mut self, min_entropy_bits: usize)
pub fn set_min_entropy_bits(&mut self, min_entropy_bits: usize)
Sourcepub fn min_entropy_bits(&self) -> usize
pub fn min_entropy_bits(&self) -> usize
Sourcepub fn set_entropy_validation(&mut self, enabled: bool)
pub fn set_entropy_validation(&mut self, enabled: bool)
Sourcepub fn is_entropy_validation_enabled(&self) -> bool
pub fn is_entropy_validation_enabled(&self) -> bool
Check if entropy validation is enabled
Returns
Returns true if entropy validation is enabled, false otherwise.